@@ -15,5 +15,7 @@ import parmesan.gas
 import parmesan.wind
 import parmesan.stats
 import parmesan.vector
+import parmesan.radiation
+import parmesan.clouds
 
 # external modules
