@@ -91,7 +91,7 @@ def absolute_humidity_from_dewpoint(dewpoint_temperature):
     Calculate the absolute humidity :math:`\rho_\mathrm{w}` from the dewpoint
     temperature :math:`T_\mathrm{d}` like
     :func:`absolute_humidity_from_water_vapour_pressure` using
-    :func:`water_vapour_pressure_over_water_magnus`:
+    :func:`saturation_water_vapour_pressure_over_water_magnus`:
 
     .. math::
 
@@ -100,8 +100,10 @@ def absolute_humidity_from_dewpoint(dewpoint_temperature):
             {R_\mathrm{H_2O} \cdot T_\mathrm{d}}
     """
     return absolute_humidity_from_water_vapour_pressure(
-        water_vapour_pressure=water_vapour_pressure_over_water_magnus(
-            temperature=dewpoint_temperature
+        water_vapour_pressure=(
+            saturation_water_vapour_pressure_over_water_magnus(
+                temperature=dewpoint_temperature
+            )
         ),
         temperature=dewpoint_temperature,
     )
